@@ -47,23 +47,24 @@ def complete(event,str,widget,self):
 
 class PMGApp(AbstractApp):
 
-   appversion     = '0.82'
+   appversion     = '0.86'
    appname       = 'PyMOL Molecular Graphics System'
-   copyright      = 'Copyright (C) 1998-2002 by Warren DeLano of\nDeLano Scientific. All rights reserved.'
+   copyright      = 'Copyright (C) 1998-2002 by Warren DeLano of\nDeLano Scientific LLC. All rights reserved.'
    contactweb     = 'http://www.pymol.org'
    contactemail   = 'warren@delanoscientific.com'
 
    def appInit(self): # create a global variable for the external gui
       pymol._ext_gui = self
       self.fifo = Queue.Queue(0)
+      self.save_file = ''
 
    def execute(self,cmmd): 
       self.fifo.put(cmmd)
 
    def buttonAdd(self,frame,text,cmd):
-      newBtn=self.createcomponent('button', (), None,
-         Button,frame,text=text,highlightthickness=0,
-         command=cmd,padx=0,pady=0)
+      newBtn=Button(frame,
+                    text=text,highlightthickness=0,
+                    command=cmd,padx=0,pady=0)
       newBtn.pack(side=LEFT,fill=BOTH,expand=YES)
       
    def createButtons(self):
@@ -154,6 +155,25 @@ class PMGApp(AbstractApp):
       else: # autocenter, deiconify, and run mainloop
          win.destroy()
 
+   def back(self):
+      if not self.history_cur:
+         self.history[0] = self.command.get()
+      self.history_cur = (self.history_cur + 1) & self.history_mask
+      self.command.set(self.history[self.history_cur])
+   
+   def forward(self):
+      if not self.history_cur:
+         self.history[0] = self.command.get()
+      self.history_cur = (self.history_cur - 1) & self.history_mask
+      self.command.set(self.history[self.history_cur])
+   
+   def do(self,cmmd):
+      self.history[0]=cmmd
+      self.history.insert(0,'') # always leave blank at 0
+      self.history.pop(self.history_mask+1)
+      self.history_cur = 0
+      cmd.do(cmmd)
+                    
    def createMain(self):
       self.command = StringVar()
       self.entry = self.createcomponent('entry', (), None,
@@ -163,24 +183,36 @@ class PMGApp(AbstractApp):
                            width=50,
                            textvariable=self.command)
       self.entry.pack(side=BOTTOM,expand=NO,fill=X)
-      self.entry.bind('<Return>',lambda event,w=self.command:
-         (cmd.do(w.get()),cmd.dirty(),w.set('')))
+      self.entry.bind('<Return>',lambda event,w=self.command,s=self:
+         (s.do(w.get()),cmd.dirty(),w.set('')))
 
       self.entry.bind('<Tab>',lambda event,w=self.command,
                       e=self.entry,s=self:
                       complete(event,w,e,s))
 
+      self.history_mask = 0xFF
+      self.history = [''] * (self.history_mask+1)
+      self.history_cur = 0
+      
+      self.entry.bind('<Up>',lambda event,w=self.command,
+                      e=self.entry,s=self:s.back())
+
+      self.entry.bind('<Down>',lambda event,w=self.command,
+                      e=self.entry,s=self:s.forward())
+
       self.output = self.createcomponent('output', (), None,
                            Pmw.ScrolledText,
                            (self.get_dataArea(),))
 
       text = self.output.component('text')
+      self.text = text
+      self.font = 'lucida console'
       if sys.platform[:5]=='linux':
-         self.my_fw_font=('lucida console',12)
+         self.my_fw_font=(self.font,12)
       elif sys.platform[:3]=='win':
-         self.my_fw_font=('lucida console',8) # Courier 9
+         self.my_fw_font=(self.font,8) # Courier 9
       else:
-         self.my_fw_font=('lucida console',10)
+         self.my_fw_font=(self.font,10)
                                                                                
       text.configure(font = self.my_fw_font)
       text.configure(width=72)
@@ -227,7 +259,9 @@ class PMGApp(AbstractApp):
          self.createButtons()
          self.createMain()
          self.lineCount = 0
-         raw_list = glob(os.environ['PYMOL_PATH']+"/modules/pmg_tk/startup/*.py*")
+         startup_pattern = re.sub(r"\/[^\/]*$","/startup/*.py*",__file__)
+         # startup_pattern = os.environ['PYMOL_PATH']+"/modules/pmg_tk/startup/*.py*"
+         raw_list = glob(startup_pattern)
          unique = {}
          for a in raw_list:
             unique[re.sub(r".*\/|\.py.*$","",a)] = 1
@@ -258,11 +292,14 @@ class PMGApp(AbstractApp):
                                          ("All Readable","*.out"),
                                          ("All Readable","*.mmd"),
                                          ("All Readable","*.mmod"),
+                                         ("All Readable","*.pse"),                                         
                                          ("PDB File","*.pdb"),
                                          ("All Files","*.*"),
                                          ("All Files","*"),                                         
-                                         ("CCP4 Map","*.ccp4"),                                         
                                          ("PDB File","*.ent"),
+                                         ("PyMOL Session","*.pse"),
+                                         ("CCP4 Map","*.ccp4"),                                         
+                                         ("XPLOR Map","*.xplor"),
                                          ("Macromodel File","*.dat"),
                                          ("Macromodel File","*.out"),
                                          ("Macromodel File","*.mmd"),
@@ -271,7 +308,6 @@ class PMGApp(AbstractApp):
                                          ("ChemPy Model","*.pkl"),
                                          ("Raster3D Scene","*.r3d"),
                                          ("SDF File","*.sdf"),
-                                         ("XPLOR Map","*.xplor"),
                                          ("ChemDraw3D File","*.cc1"),
                                          ("ChemDraw3D File","*.cc2"),
                                          ("Tinker XYZ File","*.xyz")
@@ -330,6 +366,29 @@ class PMGApp(AbstractApp):
          os.chdir(self.initialdir)	         
          cmd.log_open(ofile,'a')
 
+   def session_save(self):
+      if self.save_file!='':
+         cmd.log("save %s,format=pse\n"%(self.save_file),
+                 "cmd.save('%s',format='pse')\n"%(self.save_file))
+         cmd.save(self.save_file,"","pse")
+      else:
+         self.session_save_as()
+
+   def session_save_as(self):
+      sfile = asksaveasfilename(initialfile = self.save_file,
+                                initialdir = self.initialdir,
+                                filetypes=[
+         ("PyMOL Session File","*.pse"),
+         ])
+      if len(sfile):
+         if re.search(r"\.pse$|\.PSE$",sfile)==None:
+            sfile=sfile+".pse"
+         self.initialdir = re.sub(r"[^\/\\]*$","",sfile)
+         cmd.log("save %s,format=pse\n"%(sfile),
+                 "cmd.save('%s',format='pse')\n"%(sfile))
+         cmd.save(sfile,"",format='pse')
+         self.save_file = sfile
+   
    def file_save(self):
       lst = cmd.get_names('all')
       lst = filter(lambda x:x[0]!="_",lst)
@@ -490,6 +549,15 @@ class PMGApp(AbstractApp):
                         label=self.pad+'Open...',
                         command=self.file_open)
 
+
+      self.menuBar.addmenuitem('File', 'command', 'Save session.',
+                        label=self.pad+'Save Session',
+                        command=self.session_save)
+
+      self.menuBar.addmenuitem('File', 'command', 'Save session.',
+                        label=self.pad+'Save Session As...',
+                        command=self.session_save_as)
+
       self.menuBar.addmenuitem('File', 'command', 'Save structure file.',
                         label=self.pad+'Save Molecule...',
                         command=self.file_save)
@@ -844,12 +912,45 @@ class PMGApp(AbstractApp):
                                label='Parallel Beta Sheet',
                                command = lambda: cmd.do("_ set secondary_structure,3"))
 
-      
       self.menuBar.addmenu('Movie', 'Movie Control')
 
+      
+      self.menuBar.addcascademenu('Movie', 'Speed', 'Playback Speed',
+                                  label=self.pad+'Speed')
+
+      self.menuBar.addmenuitem('Speed', 'command', 'Maximum',
+                               label=self.pad+'Maximum',
+                               command = lambda: cmd.set("movie_delay","0",log=1))
+
+      self.menuBar.addmenuitem('Speed', 'command', '30 FPS',
+                               label=self.pad+'30 FPS',
+                               command = lambda: cmd.set("movie_delay","33",log=1))
+
+      self.menuBar.addmenuitem('Speed', 'command', '15 FPS',
+                               label=self.pad+'15 FPS',
+                               command = lambda: cmd.set("movie_delay","66",log=1))
+
+      self.menuBar.addmenuitem('Speed', 'command', '5 FPS',
+                               label=self.pad+'5 FPS',
+                               command = lambda: cmd.set("movie_delay","200",log=1))
+
+      self.menuBar.addmenuitem('Speed', 'command', '1 FPS',
+                               label=self.pad+'1 FPS',
+                               command = lambda: cmd.set("movie_delay","1000",log=1))
+
+      self.menuBar.addmenuitem('Speed', 'command', '0.3 FPS',
+                               label=self.pad+'0.3 FPS',
+                               command = lambda: cmd.set("movie_delay","3000",log=1))
+
+      self.menuBar.addmenuitem('Movie', 'command', 'Reset Meter',
+                               label=self.pad+'Reset Meter',
+                               command = lambda: cmd.do("_ meter_reset"))
+
+      self.menuBar.addmenuitem('Movie', 'separator', '')
+
       self.menuBar.addmenuitem('Movie', 'checkbutton',
                          'Photorealistic images.',
-                         label=self.pad+'Ray Trace Frames',
+                         label=self.pad+'Render Frames',
                         variable = self.setting.ray_trace_frames,
                         command = lambda s=self: s.setting.update('ray_trace_frames'))
 
@@ -859,15 +960,15 @@ class PMGApp(AbstractApp):
                         variable = self.setting.cache_frames,
                         command = lambda s=self: s.setting.update('cache_frames'))
 
-      self.menuBar.addmenuitem('Movie', 'command', 'Flush Image Cache',
-                               label=self.pad+'Flush Image Cache',
+      self.menuBar.addmenuitem('Movie', 'command', 'Flush Cache',
+                               label=self.pad+'Flush Cache',
                                command = lambda: cmd.mclear())
 
       self.menuBar.addmenuitem('Movie', 'separator', '')
 
       self.menuBar.addmenuitem('Movie', 'checkbutton',
-                         'Static Singleton Objects.',
-                         label=self.pad+'Static Singleton Objects',
+                         'Static Singletons Objects',
+                         label=self.pad+'Static Singletons',
                         variable = self.setting.static_singletons,
                         command = lambda s=self: s.setting.update('static_singletons'))
 
@@ -877,54 +978,84 @@ class PMGApp(AbstractApp):
                         variable = self.setting.all_states,
                         command = lambda s=self: s.setting.update('all_states'))
 
-      self.menuBar.addmenuitem('Movie', 'separator', '')
+
+      self.menuBar.addmenu('Rendering', 'Rendering Control')
+
+      self.menuBar.addmenuitem('Rendering', 'checkbutton',
+                         'Smooth raytracing.',
+                         label=self.pad+'Antialias',
+                        variable = self.setting.antialias,
+                        command = lambda s=self: s.setting.update('antialias'))
+
+      self.menuBar.addmenuitem('Rendering', 'separator', '')
       
-      self.menuBar.addmenuitem('Movie', 'command', 'Maximum Speed',
-                               label=self.pad+'Maximum Speed',
-                               command = lambda: cmd.set("movie_delay","0",log=1))
+      self.menuBar.addcascademenu('Rendering', 'Shadows', 'Shadows',
+                               label=self.pad+'Shadows')
 
-      self.menuBar.addmenuitem('Movie', 'command', '30 FPS',
-                               label=self.pad+'30 FPS',
-                               command = lambda: cmd.set("movie_delay","33",log=1))
+      self.menuBar.addmenuitem('Shadows', 'command', 'None',
+                               label='None',
+                               command = lambda : cmd.do("_ util.ray_shadows('none')"))
 
-      self.menuBar.addmenuitem('Movie', 'command', '15 FPS',
-                               label=self.pad+'15 FPS',
-                               command = lambda: cmd.set("movie_delay","66",log=1))
+      self.menuBar.addmenuitem('Shadows', 'command', 'Light',
+                               label='Light',
+                               command = lambda : cmd.do("_ util.ray_shadows('light')"))
 
-      self.menuBar.addmenuitem('Movie', 'command', '5 FPS',
-                               label=self.pad+'5 FPS',
-                               command = lambda: cmd.set("movie_delay","200",log=1))
+      self.menuBar.addmenuitem('Shadows', 'command', 'Matte',
+                               label='Matte',
+                               command = lambda : cmd.do("_ util.ray_shadows('matte')"))
 
-      self.menuBar.addmenuitem('Movie', 'command', '1 FPS',
-                               label=self.pad+'1 FPS',
-                               command = lambda: cmd.set("movie_delay","1000",log=1))
+      self.menuBar.addmenuitem('Shadows', 'command', 'Medium',
+                               label='Medium',
+                               command = lambda : cmd.do("_ util.ray_shadows('medium')"))
 
-      self.menuBar.addmenuitem('Movie', 'command', '0.3 FPS',
-                               label=self.pad+'0.3 FPS',
-                               command = lambda: cmd.set("movie_delay","3000",log=1))
+      self.menuBar.addmenuitem('Shadows', 'command', 'Heavy',
+                               label='Heavy',
+                               command = lambda : cmd.do("_ util.ray_shadows('heavy')"))
 
-      self.menuBar.addmenuitem('Movie', 'separator', '')
+      self.menuBar.addmenuitem('Shadows', 'command', 'Black',
+                               label='Black',
+                               command = lambda : cmd.do("_ util.ray_shadows('black')"))
 
-      self.menuBar.addmenuitem('Movie', 'command', 'Reset Meter',
-                               label=self.pad+'Reset Meter',
-                               command = lambda: cmd.do("_ meter_reset"))
+      self.menuBar.addcascademenu('Rendering', 'Texture', 'Texture',
+                               label=self.pad+'Texture')
+
+      self.menuBar.addmenuitem('Texture', 'command', 'None',
+                               label='None',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',0)"))
+
+      self.menuBar.addmenuitem('Texture', 'command', 'Matte 1',
+                               label='Matte 1',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',1)"))
+
+      self.menuBar.addmenuitem('Texture', 'command', 'Matte 2',
+                               label='Matte 2',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',4)"))
+
+      self.menuBar.addmenuitem('Texture', 'command', 'Swirl 1',
+                               label='Swirl 1',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',2)"))
+
+      self.menuBar.addmenuitem('Texture', 'command', 'Swirl 2',
+                               label='Swirl 2',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',3)"))
+
+      self.menuBar.addmenuitem('Texture', 'command', 'Fiber',
+                               label='Fiber',
+                               command = lambda : cmd.do("_ cmd.set('ray_texture',5)"))
+
+
+
+      self.menuBar.addmenuitem('Rendering', 'separator', '')
+
+      self.menuBar.addmenuitem('Rendering', 'checkbutton',
+                         'Cull Backfaces when Rendering',
+                         label=self.pad+'Cull Backfaces',
+                        variable = self.setting.backface_cull,
+                        command = lambda s=self: s.setting.update('backface_cull'))
 
       self.menuBar.addmenu('Display', 'Display Control')
 
 
-      self.menuBar.addmenuitem('Display', 'command', 'Clear Text Output',
-                               label='Clear Text',
-                               command = lambda: cmd.do("_ cls"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Hide Text Output',
-                               label='Hide Text',
-                               command = lambda: cmd.set("text","0",log=1))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Show Text Output',
-                               label='Show Text',
-                               command = lambda: cmd.set("text","1",log=1))
-
-      self.menuBar.addmenuitem('Display', 'separator', '')
       
       self.menuBar.addmenuitem('Display', 'command', 'Stereo On',
                                label='Stereo On',
@@ -953,55 +1084,85 @@ class PMGApp(AbstractApp):
 
       self.menuBar.addmenuitem('Display', 'separator', '')
 
-      self.menuBar.addmenuitem('Display', 'command', 'Maximum Performance',
+      self.menuBar.addcascademenu('Display', 'Performance', 'Performance',
+                                  label='Performance')
+
+      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Performance',
                                label='Maximum Performance',
                                command = lambda : cmd.do("_ util.performance(100)"))
 
-      self.menuBar.addmenuitem('Display', 'command', 'Reasonable Performance',
+      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Performance',
                                label='Reasonable Performance',
                                command = lambda : cmd.do("_ util.performance(66)"))
       
-      self.menuBar.addmenuitem('Display', 'command', 'Reasonable Quality',
+      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Quality',
                                label='Reasonable Quality',
                                command = lambda : cmd.do("_ util.performance(33)"))
 
-      self.menuBar.addmenuitem('Display', 'command', 'Maximum Quality',
+      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Quality',
                                label='Maximum Quality',
                                command = lambda : cmd.do("_ util.performance(0)"))
 
-      self.menuBar.addmenuitem('Display', 'separator', '')
+      self.menuBar.addcascademenu('Display', 'Background', 'Background',
+                                  label='Background')
 
-      self.menuBar.addmenuitem('Display', 'command', 'Light Shadows',
-                               label='Light Shadows',
-                               command = lambda : cmd.do("_ util.ray_shadows('light')"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Matte Shadows',
-                               label='Matte Shadows',
-                               command = lambda : cmd.do("_ util.ray_shadows('matte')"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Medium Shadows',
-                               label='Medium Shadows',
-                               command = lambda : cmd.do("_ util.ray_shadows('medium')"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Heavy Shadows',
-                               label='Heavy Shadows',
-                               command = lambda : cmd.do("_ util.ray_shadows('heavy')"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Black Shadows',
-                               label='Black Shadows',
-                               command = lambda : cmd.do("_ util.ray_shadows('black')"))
-
-      self.menuBar.addmenuitem('Display', 'separator', '')
-
-      self.menuBar.addmenuitem('Display', 'command', 'White Background',
-                               label='White Background',
+      self.menuBar.addmenuitem('Background', 'command', 'White Background',
+                               label='White',
                                command = lambda : cmd.do("_ cmd.bg_color('white')"))
 
-      self.menuBar.addmenuitem('Display', 'command', 'Black Background',
-                               label='Black Background',
+      self.menuBar.addmenuitem('Background', 'command', 'Light Grey',
+                               label='Light Grey',
+                               command = lambda : cmd.do("_ cmd.bg_color('grey80')"))
+
+      self.menuBar.addmenuitem('Background', 'command', 'Grey',
+                               label='Grey',
+                               command = lambda : cmd.do("_ cmd.bg_color('grey50')"))
+
+
+      self.menuBar.addmenuitem('Background', 'command', 'Black Background',
+                               label='Black',
                                command = lambda : cmd.do("_ cmd.bg_color('black')"))
 
+      self.menuBar.addmenuitem('Display', 'separator', '')
       
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Disable perspective.',
+                         label=self.pad+'Orthoscopic View',
+                        variable = self.setting.ortho,
+                        command = lambda s=self: s.setting.update('ortho'))
+
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Show Valences.',
+                         label=self.pad+'Show Valences',
+                        variable = self.setting.valence,
+                        command = lambda s=self: s.setting.update('valence'))
+
+
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Smooth Lines.',
+                         label=self.pad+'Smooth Lines',
+                        variable = self.setting.line_smooth,
+                        command = lambda s=self: s.setting.update('line_smooth'))
+
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Depth Cue Fog.',
+                         label=self.pad+'Depth Cue & Fog',
+                        variable = self.setting.depth_cue,
+                        command = lambda s=self: s.setting.update('depth_cue'))
+
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Two Sided Lighting.',
+                         label=self.pad+'Two Sided Lighting',
+                        variable = self.setting.two_sided_lighting,
+                        command = lambda s=self: s.setting.update('two_sided_lighting'))
+
+      self.menuBar.addmenuitem('Display', 'checkbutton',
+                         'Specular Reflections.',
+                         label=self.pad+'Specular Reflections',
+                        variable = self.setting.specular,
+                        command = lambda s=self: s.setting.update('specular'))
+
+
       self.menuBar.addmenu('Setting', 'Configuration Control')
 
       self.menuBar.addmenuitem('Setting', 'command',
@@ -1014,65 +1175,37 @@ class PMGApp(AbstractApp):
                          label=self.pad+'Colors...',
                                command = lambda s=self: ColorEditor(s))
 
-      self.menuBar.addmenuitem('Setting', 'separator', '')
-      
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Show Valences.',
-                         label=self.pad+'Show Valences',
-                        variable = self.setting.valence,
-                        command = lambda s=self: s.setting.update('valence'))
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Disable perspective.',
-                         label=self.pad+'Orthoscopic View',
-                        variable = self.setting.ortho,
-                        command = lambda s=self: s.setting.update('ortho'))
+      self.menuBar.addcascademenu('Setting', 'Output', 'Output Size',
+                                  label=self.pad+'Output Size')
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Smooth Lines.',
-                         label=self.pad+'Smooth Lines',
-                        variable = self.setting.line_smooth,
-                        command = lambda s=self: s.setting.update('line_smooth'))
+      self.menuBar.addmenuitem('Output', 'command', '8',
+                               label='8 Point',
+                               command = lambda s=self:
+                               s.text.configure(font=(s.font,8)))
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Depth Cue Fog.',
-                         label=self.pad+'Depth Cue & Ray Trace Fog',
-                        variable = self.setting.depth_cue,
-                        command = lambda s=self: s.setting.update('depth_cue'))
+      self.menuBar.addmenuitem('Output', 'command', '9',
+                               label='9 Point',
+                               command = lambda s=self:
+                               s.text.configure(font=(s.font,9)))
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Two Sided Lighting.',
-                         label=self.pad+'Two Sided Lighting',
-                        variable = self.setting.two_sided_lighting,
-                        command = lambda s=self: s.setting.update('two_sided_lighting'))
+      self.menuBar.addmenuitem('Output', 'command', '10',
+                               label='10 Point',
+                               command = lambda s=self:
+                               s.text.configure(font=(s.font,10)))
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Specular Reflections.',
-                         label=self.pad+'Specular Reflections',
-                        variable = self.setting.specular,
-                        command = lambda s=self: s.setting.update('specular'))
+      self.menuBar.addmenuitem('Output', 'command', '11',
+                               label='11 Point',
+                               command = lambda s=self:
+                               s.text.configure(font=(s.font,11)))
 
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Overlay',
-                         label=self.pad+'Overlay Text on Graphics',
-                        variable = self.setting.overlay,
-                        command = lambda s=self: s.setting.update('overlay'))
+      self.menuBar.addmenuitem('Output', 'command', '12',
+                               label='12 Point',
+                               command = lambda s=self:
+                               s.text.configure(font=(s.font,12)))
 
       self.menuBar.addmenuitem('Setting', 'separator', '')
       
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Smooth raytracing.',
-                         label=self.pad+'Antialiased Rendering',
-                        variable = self.setting.antialias,
-                        command = lambda s=self: s.setting.update('antialias'))
-
-      self.menuBar.addmenuitem('Setting', 'checkbutton',
-                         'Cull Backfaces when Rendering',
-                         label=self.pad+'Cull Backfaces when Rendering',
-                        variable = self.setting.backface_cull,
-                        command = lambda s=self: s.setting.update('backface_cull'))
-
-      self.menuBar.addmenuitem('Setting', 'separator', '')
 
       self.menuBar.addmenuitem('Setting', 'checkbutton',
                                'Ignore PDB segi.',
@@ -1104,41 +1237,58 @@ class PMGApp(AbstractApp):
                         variable = self.setting.auto_remove_hydrogens,
                         command = lambda s=self: s.setting.update('auto_remove_hydrogens'))
 
+      self.menuBar.addmenuitem('Setting', 'separator', '')
+
+
+      self.menuBar.addmenuitem('Setting', 'command', 'Show Text Output',
+                               label='Show Text',
+                               command = lambda: cmd.set("text","1",log=1))
+
+      self.menuBar.addmenuitem('Setting', 'command', 'Hide Text Output',
+                               label='Hide Text',
+                               command = lambda: cmd.set("text","0",log=1))
+
+      self.menuBar.addmenuitem('Setting', 'checkbutton',
+                         'Overlay Text Output on Graphics',
+                         label=self.pad+'Overlay Text',
+                        variable = self.setting.overlay,
+                        command = lambda s=self: s.setting.update('overlay'))
+
       
       self.menuBar.addmenu('Mouse', 'Mouse Configuration')
 
-      self.menuBar.addmenuitem('Mouse', 'command', '3 Button',
-                               label='3 Button',
+      self.menuBar.addmenuitem('Mouse', 'command', '3 Button Universal Cycle',
+                               label='3 Button Universal Cycle',
                                command = lambda: cmd.config_mouse('three_button'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '2 Button',
-                               label='2 Button',
+      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Viewing Cycle',
+                               label='2 Button Viewing Cycle',
                                command = lambda: cmd.config_mouse('two_button'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Editing',
-                               label='2 Button Editing',
+      self.menuBar.addmenuitem('Mouse', 'command', 'Setup 2 Button Editing Cycle',
+                               label='2 Button Editing Cycle',
                                command = lambda: cmd.config_mouse('two_button_editing'))
 
       self.menuBar.addmenuitem('Mouse', 'separator', '')
 
-      self.menuBar.addmenuitem('Mouse', 'command', '3 Button Viewing',
-                               label='3 Button Viewing',
+      self.menuBar.addmenuitem('Mouse', 'command', '3 Button Viewing Mode',
+                               label='3 Button Viewing Mode',
                                command = lambda: cmd.mouse('three_button_viewing'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '3 Button Editing',
-                               label='3 Button Editing',
+      self.menuBar.addmenuitem('Mouse', 'command', '3 Button Editing Mode',
+                               label='3 Button Editing Mode',
                                command = lambda: cmd.mouse('three_button_editing'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Viewing',
-                               label='2 Button Viewing',
+      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Viewing Mode',
+                               label='2 Button Viewing Mode',
                                command = lambda: cmd.mouse('two_button_viewing'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Selecting',
-                               label='2 Button Selecting',
+      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Selecting Mode',
+                               label='2 Button Selecting Mode',
                                command = lambda: cmd.mouse('two_button_selecting'))
 
-      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Editing',
-                               label='2 Button Editing',
+      self.menuBar.addmenuitem('Mouse', 'command', '2 Button Editing Mode',
+                               label='2 Button Editing Mode',
                                command = lambda: cmd.mouse('two_button_editing'))
 
       self.menuBar.addmenu('Cartoon', 'Cartoon Properties')
