@@ -12,49 +12,51 @@
 #-*
 #Z* -------------------------------------------------------------------
 
-import string
-import thread
-import cmd
+if __name__=='pymol.helping':
+   
+   import string
+   import thread
+   import cmd
 
-def show_help(cmmd): # INTERNAL
-   print "PyMOL>help %s" % cmmd
-   help(cmmd)
-   if cmd.get_setting_legacy("internal_feedback")>0.1:
-      print "(Hit ESC to hide)"
+   def show_help(cmmd): # INTERNAL
+      print "PyMOL>help %s" % cmmd
+      help(cmmd)
+      if cmd.get_setting_legacy("internal_feedback")>0.1:
+         print "(Hit ESC to hide)"
 
-def help(command = "commands"):
-   '''
+   def help(command = "commands"):
+      '''
 DESCRIPTION
 
    "help" prints out the online help for a given command.
-   
+
 USAGE
- 
+
    help command
-   '''
-   if cmd.get_setting_legacy("internal_feedback")>0.1:
-      cmd.set("text","1",quiet=1)
-   cmmd = cmd.help_sc.auto_err(command,'topic')   
-   if cmd.keyword.has_key(cmmd):
-      doc = cmd.keyword[cmmd][0].__doc__
-      if doc:
-         print "\n",string.strip(doc),"\n"
+      '''
+      if cmd.get_setting_legacy("internal_feedback")>0.1:
+         cmd.set("text","1",quiet=1)
+      cmmd = cmd.help_sc.auto_err(command,'topic')   
+      if cmd.keyword.has_key(cmmd):
+         doc = cmd.keyword[cmmd][0].__doc__
+         if doc:
+            print "\n",string.strip(doc),"\n"
+         else:
+            print "Error: sorry no help available on that command."
+      elif cmd.help_only.has_key(cmmd):
+         doc = cmd.help_only[cmmd][0].__doc__
+         if doc:
+            print "\n",string.strip(doc),"\n"
+         else:
+            print "Error: sorry no help available on that command."      
       else:
-         print "Error: sorry no help available on that command."
-   elif cmd.help_only.has_key(cmmd):
-      doc = cmd.help_only[cmmd][0].__doc__
-      if doc:
-         print "\n",string.strip(doc),"\n"
-      else:
-         print "Error: sorry no help available on that command."      
-   else:
-      print "Error: unrecognized command"
+         print "Error: unrecognized command"
 
 
-def commands():
-   '''
+   def commands():
+      '''
 COMMANDS
- 
+
    INPUT/OUTPUT  load      save      delete    quit
    VIEW          turn      move      clip      rock
                  show      hide      enable    disable
@@ -86,14 +88,14 @@ COMMANDS
    LANGUAGE      alias     extend
 
 Try "help <command-name>".  Also see the following extra topics:
- 
+
    "movies", "keyboard", "mouse", "selections",
    "examples", "launching", "editing", and "api".
-'''
-   cmd.help('commands')
-
-def editing():
    '''
+      cmd.help('commands')
+
+   def editing():
+      '''
 SUMMARY
 
 PyMOL has a rudimentary, but quite functional molecular structure
@@ -117,16 +119,16 @@ no short-cuts currently available for building common groups, but that
 is planned for later versions.
 
 NOTE
-  
+
 Only "lines" and "sticks" representations can be picked using the
 mouse, however other representations will not interfere with picking
 so long as one of these representation is present underneath.
-   
-'''
-   cmd.help('editing')
-   
-def release():
+
    '''
+      cmd.help('editing')
+
+   def release():
+      '''
 RELEASE NOTES
 
 PyMOL is a free, open, and expandable molecular graphics system
@@ -162,11 +164,11 @@ Tkinter-based GUI is going to be the default GUI for standard PyMOL
 despite its drawbacks.
 
 Warren L. DeLano (5/1/2001), warren@delanoscientific.com
-'''
-   cmd.help('release')
-
-def edit_keys():
    '''
+      cmd.help('release')
+
+   def edit_keys():
+      '''
 EDITING KEYS 
 
    These are defaults, which can be redefined.  Note that while
@@ -175,7 +177,7 @@ text editing functions instead (CTRL - A, E, and K, and DELETE), so
 you should clear the command line before trying to edit atoms.
 
 ATOM REPLACEMENT
- 
+
    CTRL-C    Replace picked atom with carbon   (C)
    CTRL-N    Replace picked atom with nitrogen (N)
    CTRL-O    Replace picked atom with oxygen   (O)
@@ -185,9 +187,9 @@ ATOM REPLACEMENT
    CTRL-L    Replace picked atom with chlorine (Cl)
    CTRL-B    Replace picked atom with bromine  (Br)
    CTRL-I    Replace picked atom with iodine   (I)
-   
+
 ATOM MODIFICATION
-  
+
    CTRL-J    Set charge on picked atom to -1
    CTRL-K    Set charge on picked atom to +1
    CTRL-D    Remove atom or bond (DELETE works too).
@@ -206,38 +208,38 @@ UNDO and REDO of conformational changes (not atom changes!)
              (you can not currently undo atom modifications).
    CTRL-A    redo the previous conformational change.
 
-'''
-   cmd.help('edit_keys')
-
-
-def at_sign():
    '''
+      cmd.help('edit_keys')
+
+
+   def at_sign():
+      '''
 DESCRIPTION
- 
+
    "@" sources a PyMOL command script as if all of the commands in the
    file were typed into the PyMOL command line.
 
 USAGE
-  
+
    @ <script-file>
 
 PYMOL API
 
    Not directly available. Instead, use cmd.do("@...").
- 
-'''
-   cmd.help(at_sign)
 
-
-def run():
    '''
+      cmd.help(at_sign)
+
+
+   def run():
+      '''
 DESCRIPTION
- 
+
    "run" executes an external Python script in a local name space, the
    global namespace, or in its own namespace (as a module).
 
 USAGE
-  
+
    run python-script [, (local | global | module | main | private ) ]
 
 PYMOL API
@@ -247,26 +249,26 @@ PYMOL API
 NOTES
 
    The default mode for run is "global".
- 
+
    Due to an idiosyncracy in Pickle, you can not pickle objects
    directly created at the main level in a script run as "module",
    (because the pickled object becomes dependent on that module).
    Workaround: delegate construction to an imported module.
 
-'''
-   cmd.help(run)
-
-def spawn():
    '''
+      cmd.help(run)
+
+   def spawn():
+      '''
 DESCRIPTION
- 
+
    "spawn" launches a Python script in a new thread which will run
    concurrently with the PyMOL interpreter. It can be run in its own
    namespace (like a Python module, default), a local name space, or
    in the global namespace.
- 
+
 USAGE
-  
+
    run python-script [, ( local | global | module | main | private )]
 
 PYMOL API
@@ -276,7 +278,7 @@ PYMOL API
 NOTES
 
    The default mode for spawn is "module".
- 
+
    Due to an idiosyncracy in Pickle, you can not pickle objects
    directly created at the main level in a script run as "module",
    (because the pickled object becomes dependent on that module).
@@ -284,38 +286,38 @@ NOTES
 
    The best way to spawn processes at startup is to use the -l option
    (see "help launching").
-'''
-   cmd.help(spawn)
-
-def api():
    '''
+      cmd.help(spawn)
+
+   def api():
+      '''
 DESCRIPTION
- 
+
    The PyMOL Python Application Programming Interface (API) should be
    accessed exclusively through the "cmd" module (never "_cmd"!).  Nearly
    all command-line functions have a corresponding API method.
- 
+
 USAGE
- 
+
    from pymol import cmd
    result = cmd.<command-name>( argument , ... ) 
-    
+
 NOTES
- 
+
    Although the PyMOL core is not multi-threaded, the API is
    thread-safe and can be called asynchronously by external python
    programs.  PyMOL handles the necessary locking to insure that
    internal states do not get corrupted.  This makes it very easy to
    build complicated systems which involve direct realtime visualization.
 
-   '''
-   
-   cmd.help('api')
+      '''
 
-def keyboard():
-   '''
+      cmd.help('api')
+
+   def keyboard():
+      '''
 KEYBOARD COMMANDS and MODIFIERS
- 
+
    ESC          Toggle onscreen text.
    INSERT       Toggle rocking.
 
@@ -324,28 +326,28 @@ KEYBOARD COMMANDS and MODIFIERS
    HOME, END    Go to the beginning or end of a movie.
 
    Command Entry Field in the Interal GUI (black window)
-   
+
    TAB          Complete commmand or filename (like in tcsh or bash).
    CTRL-A       Go to the beginning of the line.
    CTRL-E       Go to the end of the line.
    CTRL-K       Delete through to the end of the line.
 
    Command Entry Field on the External GUI (gray window).
-   
+
    CTRL-C       These operating system-provided cut and paste functions
    CTRL-V       will only work in the external GUI command line.
-   
+
 EDITING 
 
    type "help edit_keys" for keyboard shortcuts used in editing.
-   
-   '''
-   cmd.help('keyboard')
 
-def transparency():
-   '''
+      '''
+      cmd.help('keyboard')
+
+   def transparency():
+      '''
 TRANSPARENCY
- 
+
    As of version 0.68, trasparent surfaces are supported in both
    realtime (OpenGL) rendering mode as well as with ray-traced images.
 
@@ -353,26 +355,26 @@ TRANSPARENCY
    transparency variable or one attached to an individual molecule object.
 
    It isn't yet possible to control transparency on a per-atom basis.
-   
+
 EXAMPLES
 
    set transparency=0.5        # makes all surfaces 50% transparent
    set transparency=0.5, mol3  # makes only mol3's surface transparent
 
-   '''
-   cmd.help('transparency')
+      '''
+      cmd.help('transparency')
 
 
-def mouse():
-   '''
+   def mouse():
+      '''
 MOUSE CONTROLS
- 
+
   The configuration can be changed using the "Mouse" menu.  The
   current configuration is described on screen with a small matrix on
   the lower right hand corner, using the following abbreviations:
 
    Buttons (Horizontal Axis)
-   
+
       L        = left mouse click
       M        = middle mouse click
       R        = right mouse click
@@ -383,9 +385,9 @@ MOUSE CONTROLS
       Shft     = hold SHIFT down while clicking
       Ctrl     = hold CTRL down while clicking
       CtSh     = hold both SHIFT and CTRL down while clicking
-      
+
    Visualization Functions
-   
+
       Rota     = Rotates camera about X, Y, and Z axes
       RotZ     = Rotates camera about the Z axis
       Move     = Translates along the X and Y axes
@@ -399,61 +401,61 @@ MOUSE CONTROLS
       rb       = Define the (rb) selection with the indicated atom.
 
    Editing Functions
-   
+
       RotF     = Rotate fragment
       MovF     = Move fragment
       TorF     = Torsion fragment
-'''
-   cmd.help('mouse')
-
-def examples():
    '''
+      cmd.help('mouse')
+
+   def examples():
+      '''
 EXAMPLE ATOM SELECTIONS
- 
+
    select bk = ( name ca or name c or name n )
       * can be abbreviated as *
    sel bk = (n;ca,c,n)
- 
+
    select hev = ( not hydro )
       * can be abbreviated as *
    sel hev = (!h;)
- 
+
    select site = ( byres ( resi 45:52 expand 5 ))
       * can be abbreviated as *
    sel site = (b;(i;45:52 x;5))
- 
+
    select combi = ( hev and not site )
       * can be abbreviated as *
    sel combi = (hev&!site)
-   '''
-   cmd.help('examples')
-   
-def launching():
-   '''
+      '''
+      cmd.help('examples')
+
+   def launching():
+      '''
 PyMOL COMMAND LINE OPTIONS 
- 
+
    pymol.com [-ciqstwx] [ <file.pdb> ] [ <file.pml> ] [ <file.py> ] ...
- 
+
    -c   Command line mode, no GUI.  For batch opeations.
    -i   Disable the internal OpenGL GUI (object list, menus, etc.)
    -x   Disable the external GUI module.
    -t   Use Tcl/Tk based external GUI module (pmg_tk).
-   -w   Use wxPython based external GUI module (pmg_wx).
    -q   Quiet launch. Suppress splash screen & other chatter.
    -p   Listen for commands on standard input.
-   -e   Start in full-screen mode
-   -2   Start in two-button mouse mode
-   
+   -e   Start in full-screen mode.
+   -2   Start in two-button mouse mode.
+   -o   Disable security.
+
    -f <# line> Controls display of commands and feedback in OpenGL (0=off).
    -r <file.py> Run a Python program (in __main__) on startup.
    -l <file.py> Spawn a python program in new thread.
    -d <string> Run pymol command string upon startup.
    -u <script> Load and append to this PyMOL script or program file.
    -s <script> Save commands to this PyMOL script or program file.
-   
+
    <file> can have one of the following extensions, and all 
    files provided will be loaded or run after PyMOL starts.
-    
+
     .pml            PyMOL command script to be run on startup
     .py, .pym, .pyc Python program to be run on startup
     .pdb            Protein Data Bank format file to be loaded on startup
@@ -464,56 +466,56 @@ PyMOL COMMAND LINE OPTIONS
     .pkl            Pickled ChemPy Model (class "chempy.model.Indexed")
     .r3d            Raster3D Object
     .cc1, .cc2      ChemDraw 3D cartesian coordinate file
-   '''
-   cmd.help('launching')
+      '''
+      cmd.help('launching')
 
-def movies():
-   '''
+   def movies():
+      '''
 MOVIES
- 
+
    To create a movie, simply load multiple coordinate files
    into the same object.  This can be accomplish at the command line,
    using script files, or by writing PyMOL API-based programs.
- 
+
    The commands:
-   
+
 load frame001.pdb,mov
 load frame002.pdb,mov
- 
+
    will create a two frame movie.  So will the following program:
-   
+
 from pymol import cmd
-   
+
 for a in ( "frame001.pdb","frame002.pdb" ):
    cmd.load(a,"mov")
- 
+
    which can be executed at the command line using the "run" command.
-   
+
    Python built-in glob module can be useful for loading movies.
 
 from pymol import cmd
 import glob
 for a in ( glob.glob("frame*.pdb") ):
    cmd.load(a,"mov")
- 
+
 NOTE
- 
+
    Because PyMOL stores all movie frames in memory, there is a
    a practical limit to the number of atoms in all coordinate files. 
    160 MB free RAM enables 500,000 atoms with line representations.
    Complex representations require significantly more memory.
-   '''
-   cmd.help('movies')
-   
-### -------------------------------------------------------------------
-def selections():
-   '''
+      '''
+      cmd.help('movies')
+
+   ### -------------------------------------------------------------------
+   def selections():
+      '''
 DESCRIPTION
- 
+
    Selections are enclosed in parentheses and contain predicates,
    logical operations, object names, selection names and nested
    parenthesis: ( [... [(...) ... ]] )
- 
+
       name <atom names>            n. <atom names>          
       resn <residue names>         r. <residue names>
       resi <residue identifiers>   i. <residue identifiers>
@@ -545,15 +547,15 @@ DESCRIPTION
       like <selection>             l. <selection>
       <selection> within <distance> of <selection>
                        <selection> w. <distance> of <selection>      
-   '''
-   cmd.help('selections')
+      '''
+      cmd.help('selections')
 
-def povray():
-   '''
+   def povray():
+      '''
 DESCRIPTION
 
    PovRay: Persistance of Vision Support Information (EXPERIMENTAL)
-   
+
    The built-in ray-tracer (technically a ray-caster) is as fast or
    faster than PovRay for most figures (provided that hash_max is
    tuned for your system).  However, PovRay blows PyMOL away when it
@@ -565,7 +567,7 @@ DESCRIPTION
    so you must patch the source code in order to obtain this basic
    functionality required for rendering molecular surfaces.  Details
    can be found on the DINO website.
-   
+
       http://www.biozentrm.unibas.ch/~xray/dino
 
    To use PovRay, you must be running under Unix and have x-povray in
@@ -589,13 +591,13 @@ DESCRIPTION
 
    set smooth_color_triangles = 1 # is required in order to get decent
       surfaces in PovRay.  You must patch PovRay first.
-      
-   '''
-   cmd.help('povray')
+
+      '''
+      cmd.help('povray')
 
 
-def faster():
-   '''
+   def faster():
+      '''
 RAY TRACING OPTIMIZATION
 
    1. Reduce object complexity to a minimum acceptable level.
@@ -607,20 +609,20 @@ RAY TRACING OPTIMIZATION
    2. Increase "hash_max" so as to obtain a voxel dimensions of
       0.3-0.6.  Proper tuning of "hash_max" can speed up
       rendering by a factor of 2-5X for non-trivial scenes.
-      
+
       WARNING: memory usage depends on hash_max^3, so avoid
       pushing into virtual memory.  Roughly speaking:
-      
+
          hash_max = 80  -->   ~9 MB hash + data
          hash_max = 160 -->  ~72 MB hash + data
          hash_max = 240 --> ~243 MB hash + data
 
       Avoid utilizing virtual memory for the voxel hash,
       it will slow things way down.
-      
+
    3. Recompiling with optimizations on usually gives a 25-33%
       performance boost for ray tracing.
 
-   '''
+      '''
 
-   help('faster')
+      help('faster')
