@@ -54,6 +54,8 @@ ht_2pbvl = ht_2 + bvl
 Mw_2    = Mw / 2.0
 Iw_2    = Iw / 2.0
 Nw_2    = Nw / 2.0
+Nw_4    = Nw / 4.0
+Nw3_4    = Nw * 3/ 4.0
 nw_2    = nw / 2.0
 Nw_Iw   = Nw - Iw
 Nw_Iw_2 = Nw - Iw_2
@@ -799,6 +801,16 @@ plain = {
             1, iw_2, ht_2,
             ],
           ],
+   '*': [ Nsp,
+          [
+            0, 0.0, Ht_2,
+            1, Nw, Ht_2,
+            0, Nw_4, Bvl*2,
+            1, Nw3_4, Ht-Bvl*2,
+            0, Nw3_4, Bvl*2,
+            1, Nw_4, Ht-Bvl*2,
+            ],
+          ],
    '+': [ Nsp,
           [
             0, 0.0, Ht_2,
@@ -855,6 +867,12 @@ plain = {
             1, Nw, Ht,
             ],
           ],
+   '\\': [ Nsp,
+          [
+            0, 0.0, Ht,
+            1, Nw, 0.0,
+            ],
+          ],
    '%': [ Nsp,
           [
             0, 0.0, 0.0,
